@@ -110,9 +110,9 @@
 //! There are many cases where pixel transparency is important, but there are
 //! also many cases where it would just be unused memory space. Palette has
 //! therefore adopted a structure where the transparency component (alpha) is
-//! attachable using the [`Alpha`](crate::Alpha) type. This approach has shown
-//! to be very modular and easy to maintain, compared to having transparent
-//! copies of each type.
+//! attachable using the [`Alpha`] type. This approach has shown to be very
+//! modular and easy to maintain, compared to having transparent copies of each
+//! type.
 //!
 //! An additional benefit is allowing operations to selectively affect the alpha
 //! component:
@@ -250,7 +250,7 @@
 
 // Keep the standard library when running tests, too
 #![cfg_attr(all(not(feature = "std"), not(test)), no_std)]
-#![doc(html_root_url = "https://docs.rs/palette/0.7.5/")]
+#![doc(html_root_url = "https://docs.rs/palette/0.7.6/")]
 #![warn(missing_docs)]
 
 #[cfg(feature = "alloc")]
@@ -344,9 +344,11 @@ pub mod alpha;
 pub mod angle;
 pub mod blend;
 pub mod bool_mask;
+pub mod cam16;
 pub mod cast;
 pub mod chromatic_adaptation;
 pub mod color_difference;
+pub mod color_theory;
 pub mod convert;
 pub mod encoding;
 pub mod hsl;
